#!/bin/bash

#---( Zenwalk Build Script
#---( Build Script written for NumPy
#---( Home Page: http://numpy.scipy.org/
#---( Source: http://nchc.dl.sourceforge.net/sourceforge/numpy/numpy-1.3.0.tar.gz
#---( Author: R S Ananda Murthy (rsamurti@gmail.com)
#---( Date build script was last modified: Wednesday, 14-April-2009.


#------------------( Set Package Name & Version )


soft='numpy'
softversion='1.3.0'
packageversion='62.1'


#------------------( Check for Source File )


if [ -f $soft-$softversion.tar.gz  ]; then
   echo "Source file .. ok"
else
   echo "Source file does not exit. Downloading it ..."
   wget -c http://nchc.dl.sourceforge.net/sourceforge/numpy/$soft-$softversion.tar.gz
fi


#------------------( Set Package CPU Architecture Optimizations )


arch='i486'
cpu='i686'


#------------------( Set Build Location Variables )


buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"


#------------------( Clean, prepare the work area and extract the source code )


cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -rf $dest
mkdir -p $dest


#------------------( Set Build Ownerships )


chown -R root:root .
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export LAPACK="/usr/lib"
export BLAS="/usr/lib"
export FFTW="/usr/lib"


##------------------( Apply Patch, Build and Install )


cd $src
python setup.py config_fc --fcompiler=gnu95 build || return 1
python setup.py install --prefix=/usr --root=$dest


#------------------( Copy The Build Script Future Use )


mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion/build-$soft.sh
chmod +x $dest/usr/src/$soft-$softversion/build-$soft.sh


#------------------( Move Documentation and To Correct Location )


mkdir -p $dest/usr/doc/$soft-$softversion
cp -a \
   COMPATIBILITY DEV_README.txt LICENSE.txt PKG-INFO README.txt THANKS.txt \
   $dest/usr/doc/$soft-$softversion


#------------------( Create The Slackdesc )


mkdir -p $dest/install
cat <<EOF > $dest/install/slack-desc
     |-----handy-ruler------------------------------------------------------|
$soft: NumPy (An efficient array package for Python)
$soft:
$soft: NumPy is The fundamental package needed for scientific computing
$soft: with Python. This package contains:
$soft:
$soft:   * a powerful N-dimensional array object
$soft:   * sophisticated (broadcasting) functions
$soft:   * tools for integrating C/C++ and Fortran code
$soft:   * useful linear algebra, Fourier transform, and random number
$soft:     capabilities.
$soft:
EOF


#------------------( Remove Zero Length Files )


rm $dest/usr/lib/python2.6/site-packages/numpy/distutils/tests/f2py_ext/__init__.py
rm $dest/usr/lib/python2.6/site-packages/numpy/distutils/tests/swig_ext/__init__.py
rm $dest/usr/lib/python2.6/site-packages/numpy/distutils/tests/pyrex_ext/__init__.py
rm $dest/usr/lib/python2.6/site-packages/numpy/distutils/tests/f2py_f90_ext/__init__.py
rm $dest/usr/lib/python2.6/site-packages/numpy/distutils/tests/gen_ext/__init__.py


#------------------( Compress The Package And Clean Up The Work Area )


cd $dest

find . -perm 640 -exec chmod 644 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 770 -exec chmod 755 {} \;
find . -perm 700 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

makepkg -l y -c n $package.tgz
mv $package.tgz ../$package.tgz
rm -rf $src
rm -rf $dest


#------------------( Generate the MD5 Check Sum )


cd $buildir
md5sum $package.tgz > $package.md5
zen-pkgcheck.pl $package.tgz
requiredbuilder -z $package.tgz > $package.dep
